pub fn spawn(f: impl Future<Output = ()> + 'static)Available on crate feature
full only.Expand description
Spawns a future on the kernel’s async executor
The future will run to completion in the background in the context of the current thread.
This means that any access via (LocalUser)crate::ptr::LocalUser will be to the current thread’s
address space.
This also means that there is no requirement for the future to be [Send] nor [Sync].